"use client"

import { useState } from "react"
import Link from "next/link"
import Image from "next/image"
import { Play, Info, Eye, EyeOff } from "lucide-react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { Accordion, AccordionContent, AccordionItem, AccordionTrigger } from "@/components/ui/accordion"

export default function PerceptionDesRisquesPage() {
  const [showExplanation, setShowExplanation] = useState(false)

  return (
    <div className="min-h-screen bg-gray-50">
      {/* Hero section with gradient background */}
      <div className="bg-gradient-to-r from-[#3d53b6] to-[#1da7f3] text-white py-16">
        <div className="container mx-auto px-4">
          <h1 className="text-4xl md:text-5xl font-bold mb-4">Perception des Risques</h1>
          <p className="text-xl md:text-2xl max-w-3xl opacity-90">
            Apprenez à identifier et anticiper les dangers potentiels sur la route
          </p>
        </div>
      </div>

      {/* Main content */}
      <div className="container mx-auto px-4 py-12">
        {/* Explanation section */}
        <section className="mb-16">
          <div className="bg-white rounded-xl shadow-md p-6 md:p-8">
            <h2 className="text-2xl font-bold text-gray-800 mb-4 flex items-center">
              <Info className="h-6 w-6 mr-2 text-[#3d53b6]" />
              Qu'est-ce que la perception des risques ?
            </h2>

            <div className="prose max-w-none">
              <p className="text-gray-700 mb-4">
                La perception des risques est une compétence essentielle pour tout conducteur. Elle consiste à
                identifier, évaluer et anticiper les dangers potentiels sur la route avant qu'ils ne deviennent des
                situations d'urgence.
              </p>

              <div className="grid md:grid-cols-2 gap-8 my-8">
                <div className="bg-blue-50 p-6 rounded-lg border border-blue-100">
                  <h3 className="text-xl font-semibold text-gray-800 mb-3">Pourquoi est-ce important ?</h3>
                  <ul className="list-disc pl-5 space-y-2 text-gray-700">
                    <li>Réduit significativement le risque d'accident</li>
                    <li>Permet d'anticiper les comportements des autres usagers</li>
                    <li>Donne plus de temps pour réagir face aux dangers</li>
                    <li>Améliore la prise de décision en situation de conduite</li>
                    <li>Fait partie des compétences évaluées lors de l'examen du permis</li>
                  </ul>
                </div>

                <div className="bg-amber-50 p-6 rounded-lg border border-amber-100">
                  <h3 className="text-xl font-semibold text-gray-800 mb-3">Comment améliorer cette compétence ?</h3>
                  <ul className="list-disc pl-5 space-y-2 text-gray-700">
                    <li>Pratiquer régulièrement avec des exercices dédiés</li>
                    <li>Observer activement l'environnement routier</li>
                    <li>Anticiper les actions des autres usagers</li>
                    <li>Maintenir une distance de sécurité suffisante</li>
                    <li>Adapter sa vitesse aux conditions de circulation</li>
                  </ul>
                </div>
              </div>

              <p className="text-gray-700 mb-4">
                Lors de l'examen du permis de conduire, vous serez évalué sur votre capacité à percevoir les risques
                potentiels et à adapter votre conduite en conséquence. Les exercices ci-dessous vous aideront à
                développer cette compétence cruciale.
              </p>

              <div className="bg-gray-100 p-4 rounded-lg border border-gray-200 mb-6">
                <h3 className="text-lg font-semibold text-gray-800 mb-2">À savoir :</h3>
                <p className="text-gray-700">
                  Les exercices de perception des risques utilisent souvent des vidéos ou des images de situations
                  réelles de conduite. Vous devrez identifier rapidement les dangers potentiels et expliquer comment
                  vous adapteriez votre conduite.
                </p>
              </div>
            </div>

            <Accordion type="single" collapsible className="mt-6">
              <AccordionItem value="faq-1">
                <AccordionTrigger className="text-lg font-medium text-gray-800">
                  Questions fréquentes sur la perception des risques
                </AccordionTrigger>
                <AccordionContent>
                  <div className="space-y-4 pt-2">
                    <div>
                      <h4 className="font-medium text-gray-800">
                        Comment se déroule l'épreuve de perception des risques à l'examen ?
                      </h4>
                      <p className="text-gray-700 mt-1">
                        Pendant l'examen, l'examinateur vous montrera des images ou des vidéos de situations de
                        conduite. Vous devrez identifier les dangers potentiels et expliquer comment vous adapteriez
                        votre conduite.
                      </p>
                    </div>
                    <div>
                      <h4 className="font-medium text-gray-800">Combien de temps ai-je pour répondre ?</h4>
                      <p className="text-gray-700 mt-1">
                        Généralement, vous disposez de 15 à 20 secondes pour identifier les risques dans chaque
                        situation présentée.
                      </p>
                    </div>
                    <div>
                      <h4 className="font-medium text-gray-800">
                        Quels sont les risques les plus couramment négligés ?
                      </h4>
                      <p className="text-gray-700 mt-1">
                        Les piétons, les cyclistes, les angles morts, les conditions météorologiques défavorables et les
                        comportements imprévisibles des autres conducteurs sont souvent sous-estimés.
                      </p>
                    </div>
                  </div>
                </AccordionContent>
              </AccordionItem>
            </Accordion>
          </div>
        </section>

        {/* Exercise section */}
        <section>
          <h2 className="text-2xl font-bold text-gray-800 mb-6">Exercices de perception des risques</h2>

          <Card className="bg-gradient-to-br from-cyan-50 to-blue-50 border-cyan-200 hover:border-cyan-300 transition-all duration-300 shadow-md">
            <CardHeader className="pb-4">
              <div className="flex items-center justify-between">
                <div className="flex items-center">
                  <div className="w-12 h-12 rounded-full bg-cyan-100 flex items-center justify-center mr-4">
                    <span className="text-2xl">👁️</span>
                  </div>
                  <div>
                    <CardTitle className="text-xl text-gray-800">Perception des risques</CardTitle>
                    <CardDescription className="text-gray-600">
                      Identifiez rapidement les dangers potentiels dans diverses situations de conduite
                    </CardDescription>
                  </div>
                </div>
              </div>
            </CardHeader>
            <CardContent>
              <div className="grid md:grid-cols-3 gap-4 text-sm">
                <div className="flex items-center">
                  <div className="w-8 h-8 rounded-full bg-cyan-100 flex items-center justify-center mr-2">
                    <span className="text-cyan-700 font-medium">20</span>
                  </div>
                  <span className="text-gray-700">Questions</span>
                </div>
                <div className="flex items-center">
                  <div className="w-8 h-8 rounded-full bg-cyan-100 flex items-center justify-center mr-2">
                    <span className="text-cyan-700 font-medium">15</span>
                  </div>
                  <span className="text-gray-700">Minutes</span>
                </div>
                <div className="flex items-center">
                  <div className="w-8 h-8 rounded-full bg-cyan-100 flex items-center justify-center mr-2">
                    <span className="text-cyan-700 font-medium">70%</span>
                  </div>
                  <span className="text-gray-700">Score minimum</span>
                </div>
              </div>

              {/* Example question preview */}
              <div className="mt-6 bg-white rounded-lg border border-gray-200 p-4">
                <h3 className="font-medium text-gray-800 mb-2">Exemple de question :</h3>
                <div className="relative aspect-video bg-gray-200 rounded-md mb-4 overflow-hidden">
                  <Image
                    src="/placeholder.svg?height=400&width=600"
                    alt="Situation de conduite"
                    width={600}
                    height={400}
                    className="object-cover"
                  />
                  <div className="absolute inset-0 flex items-center justify-center">
                    <span className="text-gray-500">Image de situation routière</span>
                  </div>
                </div>
                <p className="text-gray-700 mb-3">
                  Identifiez les dangers potentiels dans cette situation et expliquez comment vous adapteriez votre
                  conduite.
                </p>

                <div className="flex justify-between items-center">
                  <Button
                    variant="outline"
                    size="sm"
                    onClick={() => setShowExplanation(!showExplanation)}
                    className="text-gray-700"
                  >
                    {showExplanation ? (
                      <>
                        <EyeOff className="h-4 w-4 mr-1" /> Masquer l'explication
                      </>
                    ) : (
                      <>
                        <Eye className="h-4 w-4 mr-1" /> Voir l'explication
                      </>
                    )}
                  </Button>
                </div>

                {showExplanation && (
                  <div className="mt-3 p-3 bg-amber-50 border border-amber-100 rounded-md">
                    <h4 className="font-medium text-gray-800 mb-1">Explication :</h4>
                    <p className="text-gray-700">
                      Dans cette situation, les dangers potentiels sont : le piéton qui pourrait traverser, la voiture
                      garée qui masque la visibilité, et l'intersection proche. Il faudrait ralentir, se tenir prêt à
                      freiner et vérifier les angles morts.
                    </p>
                  </div>
                )}
              </div>
            </CardContent>
            <CardFooter className="pt-2">
              <Link href="/perception-des-risques/exercice" className="w-full">
                <Button className="w-full bg-cyan-600 hover:bg-cyan-700">
                  <Play className="h-4 w-4 mr-2" /> Commencer l'exercice
                </Button>
              </Link>
            </CardFooter>
          </Card>
        </section>
      </div>
    </div>
  )
}
